@@ -41,12 +41,11 @@ def make_counts(
                 reads.append(line)
                 j += 1
                 if j % 1000 == 0:
-                    print(f"Processed {j} reads.")
                     results.append(
                         pool.apply_async(
                             Counts.process,
                             (
-                                line,
+                                reads,
                                 regex,
                                 library.get_iter(),
                             ),
@@ -71,11 +70,8 @@ def make_counts(
         for guide in guides:
             i += 1
             if guide in counts.count_map:
-                print("slotted:", guide)
                 counts.count_map[guide] += 1
                 if i % 1000 == 0:
                     print(f"Processed {i} guides.")
-            else:
-                print("could not:", guide)
 
     counts.to_csv()
